@@ -21,10 +21,10 @@ INSTDIR="$(pwd)/inst"
 export ITCLVERS SRC SRCURL BUILDDIR OUTDIR INSTDIR
 
 # Set configure options for this sub-project
-LDFLAGS="${KC_ITCL_LDFLAGS}"
-CFLAGS="${KC_ITCL_CFLAGS}"
-CPPFLAGS="${KC_ITCL_CPPFLAGS}"
-LIBS="${KC_ITCL_LIBS}"
+LDFLAGS="${LDFLAGS} ${KC_ITCL_LDFLAGS}"
+CFLAGS="${CFLAGS} ${KC_ITCL_CFLAGS}"
+CPPFLAGS="${CPPFLAGS} ${KC_ITCL_CPPFLAGS}"
+LIBS="${LIBS} ${KC_ITCL_LIBS}"
 export LDFLAGS CFLAGS CPPFLAGS LIBS
 
 rm -rf 'build' 'out' 'inst'
