@@ -21,10 +21,11 @@ PATCHDIR="$(pwd)/patches"
 export MK4VERS SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHDIR
 
 # Set configure options for this sub-project
-LDFLAGS="${KC_MK4TCL_LDFLAGS}"
-CFLAGS="${KC_MK4TCL_CFLAGS}"
-CPPFLAGS="${KC_MK4TCL_CPPFLAGS}"
-LIBS="${KC_MK4TCL_LIBS}"
+LDFLAGS="${LDFLAGS} ${KC_MK4TCL_LDFLAGS}"
+CFLAGS="${CFLAGS} ${KC_MK4TCL_CFLAGS}"
+CXXFLAGS="${CXXFLAGS} ${KC_MK4TCL_CXXFLAGS}"
+CPPFLAGS="${CPPFLAGS} ${KC_MK4TCL_CPPFLAGS}"
+LIBS="${LIBS} ${KC_MK4TCL_LIBS}"
 export LDFLAGS CFLAGS CPPFLAGS LIBS
 
 rm -rf 'build' 'out' 'inst'
